@@ -711,13 +711,34 @@ our %strip = (
 	'^and limitations of warranty.  Please limit',
 	'^minute and one connection.',
     ],
+    'whois.nordnet.net' => [
+	'^Serveur Whois version',
+	'^\*\*\*\*\*\*\*\*\*',
+	'^\* Base de Donnees des domaines COM, NET et ORG',
+	'^\* enregistres par NORDNET.                    ',
+	'^\* Ces informations sont affichees par le serve',
+	'^\* Whois de NORDNET, le Registrar du           ',
+	'^\* Groupe FRANCE-TELECOM                       ',
+	'^\* Elles ne peuvent etre utilisees sans l accor',
+	'^\* prealable de NORDNET.                       ',
+	'^\*                                             ',
+	'^\* Database of registration for COM, NET and   ',
+	'^\* ORG by NORDNET.                             ',
+	'^\* This informations is from NORDNET s Whois   ',
+	'^\* Server, the Registrar for the               ',
+	'^\* Group FRANCE-TELECOM.                       ',
+	'^\* Use of this data is strictly prohibited with',
+	'^\* out proper authorisation of NORDNET.',
+	'^Deposez votre domaine sur le site http://www.nordnet.net',
+	'^Copyright Nordnet Registrar',
+    ],
 );
 
 our %exceed = (
     'whois.eu' => 'Excessive querying, grace period of',
     'whois.dns.lu' => 'Excessive querying, grace period of',
     'whois.mynic.net.my' => 'Query limitation is',
-    'whois.ripn.net' => 'excessive querying of the WHOIS database',
+    'whois.ripn.net' => 'exceeded allowed connection rate',
     'whois.domain-registry.nl' => 'too many requests',
     'whois.nic.uk' => 'and will be replenished',
 );
